/**
	*****************************************************************************
	* @file		defines.h
	* @author	Kenn Sebesta
	* @version 	V3.1.2
	* @date		2011/03
	* @brief		This file contains definitions for the PS3 Move's buttons, LEDs,
	*					sensors, and modules.
	*****************************************************************************
	* @copy
	*
	* <h2><center>&copy; COPYRIGHT 2011 Kenn Sebesta</center></h2>
	*/

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __DEFINES_H
#define __DEFINES_H

/** @defgroup PS3_Move_Exported_Constants
	* @{
	*/
/** @addtogroup GP_DIO
	* @{
	*/
#define BUTTON_PS_PORT			GPIOA
#define BUTTON_PS_PIN			GPIO_Pin_0

#define BUTTON_SELECT_PORT		GPIOB
#define BUTTON_SELECT_PIN		GPIO_Pin_8

#define BUTTON_START_PORT		GPIOB
#define BUTTON_START_PIN		GPIO_Pin_9

#define BUTTON_CIRCLE_PORT		GPIOC
#define BUTTON_CIRCLE_PIN		GPIO_Pin_13

#define BUTTON_X_PORT			GPIOC
#define BUTTON_X_PIN				GPIO_Pin_14

#define BUTTON_TRIANGLE_PORT	GPIOC
#define BUTTON_TRIANGLE_PIN	GPIO_Pin_15

#define BUTTON_SQUARE_PORT		GPIOD
#define BUTTON_SQUARE_PIN		GPIO_Pin_5

#define BUTTON_MOVE_PORT		GPIOE
#define BUTTON_MOVE_PIN			GPIO_Pin_0

#define LED_R_PORT				GPIOC
#define LED_R_PIN					GPIO_Pin_6

#define LED_G_PORT				GPIOC
#define LED_G_PIN					GPIO_Pin_7

#define LED_B_PORT				GPIOC
#define LED_B_PIN					GPIO_Pin_8

#define PWR_ENABLE_PORT			GPIOD
#define PWR_ENABLE_PIN			GPIO_Pin_11

#define GYRO_PIN_7_PORT			GPIOC
#define GYRO_PIN_7_PIN			GPIO_Pin_4

#define MAG_DATA_RDY_PORT		GPIOE
#define MAG_DATA_RDY_PIN		GPIO_Pin_12

#define USB_PLUGGED_IN_PORT	GPIOD		//UNSURE IF THIS IS TRUE OR NOT. WHAT IS CLEAR IS THAT THIS PIN GOES `HI` WHEN USB PLUGGED IN, AND `LO` WHEN NOT
#define USB_PLUGGED_IN_PIN		GPIO_Pin_7

/**
	* @}
	*/

/** @addtogroup AIO
	* @{
	*/
#define ACC_X_PORT					GPIOA
#define ACC_X_PIN						GPIO_Pin_1
#define ACC_X_ADC						ADC1
#define ACC_X_IO_CHANNEL			ADC_Channel_1
#define ACC_X_ADC_NUMBER			1

#define ACC_Z_PORT					GPIOA
#define ACC_Z_PIN						GPIO_Pin_3
#define ACC_Z_ADC						ADC1
#define ACC_Z_IO_CHANNEL			ADC_Channel_3
#define ACC_Z_ADC_NUMBER			1

#define ACC_Y_PORT					GPIOC
#define ACC_Y_PIN						GPIO_Pin_3
#define ACC_Y_ADC						ADC1
#define ACC_Y_IO_CHANNEL			ADC_Channel_13
#define ACC_Y_ADC_NUMBER			2

#define GYRO_Y_PORT					GPIOC
#define GYRO_Y_PIN					GPIO_Pin_0
#define GYRO_Y_ADC					ADC1
#define GYRO_Y_IO_CHANNEL			ADC_Channel_10
#define GYRO_Y_ADC_NUMBER			2

#define GYRO_X_PORT					GPIOC
#define GYRO_X_PIN					GPIO_Pin_1
#define GYRO_X_ADC					ADC1
#define GYRO_X_IO_CHANNEL			ADC_Channel_11
#define GYRO_X_ADC_NUMBER			3

#define GYRO_Z_PORT					GPIOC
#define GYRO_Z_PIN					GPIO_Pin_2
#define GYRO_Z_ADC					ADC1
#define GYRO_Z_IO_CHANNEL			ADC_Channel_12
#define GYRO_Z_ADC_NUMBER			3

#define TRIGGER_Z_PORT				GPIOB
#define TRIGGER_Z_PIN				GPIO_Pin_1
#define TRIGGER_Z_ADC				ADC1
#define TRIGGER_Z_IO_CHANNEL		ADC_Channel_9
#define TRIGGER_Z_ADC_NUMBER		4

#define PS3_ADC_CHANNELS			{ ACC_X_IO_CHANNEL, ACC_Y_IO_CHANNEL, ACC_Z_IO_CHANNEL, GYRO_X_IO_CHANNEL, GYRO_Y_IO_CHANNEL, GYRO_Z_IO_CHANNEL, TRIGGER_Z_IO_CHANNEL }
#define PS3_ADC_MAPPING				{ ACC_X_ADC, ACC_Y_ADC, ACC_Z_ADC, GYRO_X_ADC, GYRO_Y_ADC, GYRO_Z_ADC, TRIGGER_Z_ADC }
#define PS3_ADC_CHANNEL_MAPPING	{ ACC_X_ADC_NUMBER, ACC_Y_ADC_NUMBER, ACC_Z_ADC_NUMBER, GYRO_X_ADC_NUMBER, GYRO_Y_ADC_NUMBER, GYRO_Z_ADC_NUMBER, TRIGGER_Z_ADC_NUMBER }

#define PS3_ADC_NUM_PINS			7
#define PS3_ADC_NUM_CHANNELS		2
#define PS3_ADC_ADCCLK				ADC_SampleTime_1Cycles5
/**
	* @}
	*/

/** @addtogroup I2C_IO
	* @{
	*/
#define I2C2_SCK_PORT				GPIOB
#define I2C2_SCK_PIN					GPIO_Pin_10

#define I2C2_SDA_PORT				GPIOB
#define I2C2_SDA_PIN					GPIO_Pin_11


#define I2C2_CLOCK_SPEED			400000
#define MAG_I2C_ADDRESS				0x1E //This is the left-aligned address

// AK8974 registers. This data was taken from akm8974.c, a Linux kernel patch


#define AK8974_SELFTEST	 			0x0C
#define AK8974_INFO	 				0x0D
#define AK8974_WHOAMI	 			0x0F
#define AK8974_DATA_X	 			0x10
#define AK8974_DATA_Y				0x12
#define AK8974_DATA_Z				0x14
#define AK8974_INT_SRC				0x16
#define AK8974_STATUS	 			0x18
#define AK8974_INT_CLEAR			0x1A
#define AK8974_CTRL1	 				0x1B
#define AK8974_CTRL2	 				0x1C
#define AK8974_CTRL3	 				0x1D
#define AK8974_INT_CTRL				0x1E
#define AK8974_OFFSET_X				0x20
#define AK8974_OFFSET_Y				0x22
#define AK8974_OFFSET_Z				0x24
#define AK8974_INT_THRES			0x26 /* absolute any axis value threshold */
#define AK8974_PRESET				0x30
#define AK8974_TEMP					0x31

#define AK8974_SELFTEST_IDLE		0x55
#define AK8974_SELFTEST_OK			0xAA

#define AK8974_WHOAMI_VALUE_AK8974 0x48
#define AK8974_INT_X_HIGH			0x80 /* Axis over +threshold */
#define AK8974_INT_Y_HIGH			0x40
#define AK8974_INT_Z_HIGH			0x20
#define AK8974_INT_X_LOW			0x10 /* Axis below -threshold	*/
#define AK8974_INT_Y_LOW			0x08
#define AK8974_INT_Z_LOW			0x04
#define AK8974_INT_RANGE			0x02 /* Range overflow (any axis) */

#define AK8974_STATUS_DRDY			0x40 /* Data ready	 */
#define AK8974_STATUS_OVERRUN		0x20 /* Data overrun	 */
#define AK8974_STATUS_INT			0x10 /* Interrupt occurred */

#define AK8974_CTRL1_POWER			0x80 /* 0 = standby; 1 = active */
#define AK8974_CTRL1_RATE			0x10 /* 0 = 10 Hz; 1 = 20 Hz	 */
#define AK8974_CTRL1_FORCE_EN		0x02 /* 0 = normal; 1 = force	 */
#define AK8974_CTRL1_MODE2			0x01 /* 0 */

#define AK8974_CTRL2_INT_EN		0x10 /* 1 = enable interrupts	 */
#define AK8974_CTRL2_DRDY_EN		0x08 /* 1 = enable data ready signal */
#define AK8974_CTRL2_DRDY_POL		0x04 /* 1 = data ready active high */
#define AK8974_CTRL2_RESDEF		(AK8974_CTRL2_DRDY_POL)

#define AK8974_CTRL3_RESET			0x80 /* Software reset	 */
#define AK8974_CTRL3_FORCE			0x40 /* Start forced measurement */
#define AK8974_CTRL3_SELFTEST		0x10 /* Set selftest register	 */
#define AK8974_CTRL3_RESDEF		0x00

#define AK8974_INT_CTRL_XEN		0x80 /* Enable interrupt for this axis */
#define AK8974_INT_CTRL_YEN		0x40
#define AK8974_INT_CTRL_ZEN		0x20
#define AK8974_INT_CTRL_XYZEN		0xE0
#define AK8974_INT_CTRL_POL		0x08 /* 0 = active low; 1 = active high */
#define AK8974_INT_CTRL_PULSE		0x02 /* 0 = latched;	 1 = pulse (50 usec) */
#define AK8974_INT_CTRL_RESDEF	(AK8974_INT_CTRL_XYZEN | AK8974_INT_CTRL_POL)

#define AK8974_INT_SCR_MROI		0x02

/**
	* @}
	*/

/**
	* @}
	*/

#endif