/**
	******************************************************************************
	* @file		main.c
	* @author	Kenn Sebesta
	* @version 	V3.1.2
	* @date		2011/03
	* @brief		Main program body.
	******************************************************************************
	* @copy
	*
	* <h2><center>&copy; COPYRIGHT 2011 Kenn Sebesta</center></h2>
	*/

/* Includes ------------------------------------------------------------------*/
#include "stm32f10x.h"
#include "init.h"
#include "defines.h"
#include "I2CRoutines.h"

/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
extern GPIO_InitTypeDef GPIO_InitStructure;
/* Buffer of data to be received by I2C2 */
uint8_t Buffer_Rx2[6];

/* Buffer of data to be transmitted by I2C2 */
uint8_t Buffer_Tx2[2];

extern __IO uint8_t Tx_Idx2, Rx_Idx2;

/* Private function prototypes -----------------------------------------------*/
void RCC_Configuration(void);
void Delay(__IO uint32_t nCount);

/* Private functions ---------------------------------------------------------*/

/**
	* @brief	Main program.
	* @param	None
	* @retval None
	*/
int main(void)
{
	/* System Clocks Configuration *********************************************/
	RCC_Configuration();	

	/* System Pin Configurations ***********************************************/
	pinsInit(); //Initialize all pins
	analogPinsInit();
	magDataPinInit();
	buttonsInit();
	ledsInit();
	pwrEnableInit();

	/* ADC Configuration *******************************************************/	
	adcInitPIOS();
	
	/* I2C Configuration *******************************************************/	
	i2cInit();

	/* Configure the magnetometer **********************************************/
	//wait 1ms
	Delay(56L*100);

	I2C_Master_BufferRead(I2C2, Buffer_Tx2, 0, Polling, 0xFE); //This transmission doesn't seem to be necessary, but Sony does it so I do it, too.
	
	//wait 1ms
	Delay(56L*100);
	
	/*Read register CTRL1 */ //This transmission doesn't seem to be necessary, but Sony does it so I do it, too.
	Buffer_Tx2[0]=AK8974_CTRL1;
	I2C_Master_BufferWrite(I2C2, Buffer_Tx2, 1, Polling, MAG_I2C_ADDRESS);
	I2C_Master_BufferRead(I2C2,  Buffer_Rx2, 1, Polling, MAG_I2C_ADDRESS);
	
	//wait 1ms
	Delay(56L*100);
	
	/*Write 'force enable' to register CTRL1.  Force state means it only starts
	measuring when bit6 of CTNL_3 is set */
	Buffer_Tx2[0]=AK8974_CTRL1;
	Buffer_Tx2[1]=AK8974_CTRL1_FORCE_EN;
	I2C_Master_BufferWrite(I2C2, Buffer_Tx2, 2, Polling, MAG_I2C_ADDRESS);
	
	//wait 2ms
	Delay(56L*200);
	
	/*Write power on to register CTRL1 */
	/*Write 'force enable' a second time to register CTRL1.  Force state means
	it only starts measuring when bit6 of CTNL_3 is set */
	Buffer_Tx2[0]=AK8974_CTRL1;
	Buffer_Tx2[1]=(AK8974_CTRL1_POWER | AK8974_CTRL1_FORCE_EN);
	I2C_Master_BufferWrite(I2C2, Buffer_Tx2, 2, Polling, MAG_I2C_ADDRESS);
	
	//wait 1.5ms
	Delay(56L*150);
	
	/*Read register CTRL2 */ //This transmission doesn't seem to be necessary, but Sony does it so I do it, too.
	Buffer_Tx2[0]=AK8974_CTRL2;
	I2C_Master_BufferWrite(I2C2, Buffer_Tx2, 1, Polling, MAG_I2C_ADDRESS);
	I2C_Master_BufferRead(I2C2,  Buffer_Rx2, 1, Polling, MAG_I2C_ADDRESS);
	
	//wait 2ms
	Delay(56L*200);
	
	/*Write power on to register CTRL1 */
	/*Write 'force enable' to register CTRL1.  Force state means it only
	starts measuring when bit6 of CTNL_3 is set */
	Buffer_Tx2[0]=AK8974_CTRL1;
	Buffer_Tx2[1]=( AK8974_CTRL1_POWER | AK8974_CTRL1_FORCE_EN );
	I2C_Master_BufferWrite(I2C2, Buffer_Tx2, 2, Polling, MAG_I2C_ADDRESS);
	
	//wait 1.5ms
	Delay(56L*150);
	
	Buffer_Tx2[0]=AK8974_CTRL2;
	I2C_Master_BufferWrite(I2C2, Buffer_Tx2, 1, Polling, MAG_I2C_ADDRESS);
	I2C_Master_BufferRead(I2C2,  Buffer_Rx2, 1, Polling, MAG_I2C_ADDRESS);
	
	//wait 1ms
	Delay(56L*100);
	
	/*Turn on enable data ready signal*/
	/*Configure enable data ready signal to HI*/
	Buffer_Tx2[0]=AK8974_CTRL2;
	Buffer_Tx2[1]=( AK8974_CTRL2_DRDY_EN | AK8974_CTRL2_DRDY_POL );
	I2C_Master_BufferWrite(I2C2, Buffer_Tx2, 2, Polling, MAG_I2C_ADDRESS);
	
	//wait 6ms
	Delay(56L*600);
	
	
	/* Enable secondary power-up circuit ***************************************/	
	PWR_ENABLE_PORT->BSRR=PWR_ENABLE_PIN;	//Enable switching-regulator ON
	
	/* START INFINITE LOOP *****************************************************/
	volatile int channel;
	volatile int val;
	
	volatile char button_PS;
	volatile char button_Move;
	volatile char button_Start;
	volatile char button_Select;
	volatile char button_Circle;
	volatile char button_X;
	volatile char button_Square;
	volatile char button_Triangle;

	volatile char plug_USB;
	
	
	for (;;){
		/* Measure ADC channels *************************************************/
		channel=ACC_Y_IO_CHANNEL; //Choose the Analog channel to measure.
		for (int i=0; i<1; i++){ //Cycle through ADC channels
			ADC_RegularChannelConfig(ADC1, channel, 1, ADC_SampleTime_1Cycles5);
			// Start the conversion
			ADC_SoftwareStartConvCmd(ADC1, ENABLE);
			// Wait until conversion completion
			while(ADC_GetFlagStatus(ADC1, ADC_FLAG_EOC) == RESET);
			// Get the conversion value
			val=ADC_GetConversionValue(ADC1);
		}

		/* Configure the magnetometer **********************************************/
		
		//THIS SECTION SHOULD NOT BE REPEATED HERE. HOWEVER, THERE SEEMS TO BE A
		//BUG IN STM'S FIRMWARE THAT MAKES I2C NOT WORK RIGHT THE FIRST TEN OR
		//TWENTY TIMES. FOR SOME REASON, THE CLOCK GETS STUCK 'lo' AFTER THE EXIT
		//FROM I2C_Master_BufferWrite/Read. THIS NEEDS TO BE INVESTIGATED.

		//wait 1.5ms
		Delay(56L*150);
		
		/*Write power on to register CTRL1 */
		/*Write 'force enable' to register CTRL1.  Force state means it only
		starts measuring when bit6 of CTNL_3 is set */
		Buffer_Tx2[0]=AK8974_CTRL1;
		Buffer_Tx2[1]=( AK8974_CTRL1_POWER | AK8974_CTRL1_FORCE_EN );
		I2C_Master_BufferWrite(I2C2, Buffer_Tx2, 2, Polling, MAG_I2C_ADDRESS);
		
		//wait 1.5ms
		Delay(56L*150);
		
		Buffer_Tx2[0]=AK8974_CTRL2;
		I2C_Master_BufferWrite(I2C2, Buffer_Tx2, 1, Polling, MAG_I2C_ADDRESS);
		I2C_Master_BufferRead(I2C2,  Buffer_Rx2, 1, Polling, MAG_I2C_ADDRESS);
		
		//wait 1ms
		Delay(56L*100);
		
		/*Turn on enable data ready signal*/
		/*Configure enable data ready signal to HI*/
		Buffer_Tx2[0]=AK8974_CTRL2;
		Buffer_Tx2[1]=( AK8974_CTRL2_DRDY_EN | AK8974_CTRL2_DRDY_POL );
		I2C_Master_BufferWrite(I2C2, Buffer_Tx2, 2, Polling, MAG_I2C_ADDRESS);
		
		//wait 6ms
		Delay(56L*600);
		
		/* Read the magnetometer ************************************************/
		//wait 3.4ms
		Delay(56L*340);
		
		Buffer_Tx2[0]=AK8974_CTRL3;
		I2C_Master_BufferWrite(I2C2, Buffer_Tx2, 1, Polling, MAG_I2C_ADDRESS);
		I2C_Master_BufferRead(I2C2,  Buffer_Rx2, 1, Polling, MAG_I2C_ADDRESS);
		
		Buffer_Tx2[0]=AK8974_CTRL3;
		Buffer_Tx2[1]=AK8974_CTRL3_FORCE;
		I2C_Master_BufferWrite(I2C2, Buffer_Tx2, 2, Polling, MAG_I2C_ADDRESS);
		
		//wait 6.25ms
		Delay(56L*625);
		
		/* Read 6 sequential registers, starting with X_LOW. Oftentimes, I2C
		protocols are implemented in such a way that you can keep reading
		sequential registers as long as the clock signal keeps going. */
		Buffer_Tx2[0]=AK8974_INT_X_LOW;
		I2C_Master_BufferWrite(I2C2, Buffer_Tx2, 1, Polling, MAG_I2C_ADDRESS);
		I2C_Master_BufferRead(I2C2,  Buffer_Rx2, 6, Polling, MAG_I2C_ADDRESS);
			

		/* Cycle LEDs ***********************************************************/
	  	LED_R_PORT->BSRR=LED_R_PIN;	//Red LED on
	  	LED_R_PORT->BRR=LED_R_PIN;		//Red LED off

	  	LED_G_PORT->BSRR=LED_G_PIN;	//Green LED on
	  	LED_G_PORT->BRR=LED_G_PIN;		//Green LED off
		
	  	LED_B_PORT->BSRR=LED_B_PIN;	//Blue LED on
	  	LED_B_PORT->BRR=LED_B_PIN;		//Blue LED off
		
		
		/* Check buttons ********************************************************/
		//The buttons return a 1 if pressed, otherwise 0.
		button_PS=(BUTTON_PS_PORT->IDR & BUTTON_PS_PIN) ? 1:0;
		button_Move=(BUTTON_MOVE_PORT->IDR & BUTTON_MOVE_PIN) ? 1:0;
		button_Start=(BUTTON_START_PORT->IDR & BUTTON_START_PIN) ? 1:0;
		button_Select=(BUTTON_SELECT_PORT->IDR & BUTTON_SELECT_PIN) ? 1:0;
		button_Circle=(BUTTON_CIRCLE_PORT->IDR & BUTTON_CIRCLE_PIN) ? 1:0;
		button_X=(BUTTON_X_PORT->IDR & BUTTON_X_PIN) ? 1:0;
		button_Square=(BUTTON_SQUARE_PORT->IDR & BUTTON_SQUARE_PIN) ? 1:0;
		button_Triangle=(BUTTON_TRIANGLE_PORT->IDR & BUTTON_TRIANGLE_PIN) ? 1:0;

		/* Check USB ************************************************************/
		//Return a 1 if pressed, otherwise 0.
		//UNSURE IF THIS PIN IS REALLY DIRECTLY CONNECTED TO USB POWER, OR IF IS
		//SIMPLY IS CLOSELY RELATED. IN ANY CASE, IT GOES `HI` WHEN USB IS PLUGGED
		//IN, AND `LO` OTHERWISE.
		plug_USB=(USB_PLUGGED_IN_PORT->IDR & USB_PLUGGED_IN_PIN) ? 1:0;

	}
	
}

/**
	* @brief	Configures the different system clocks.
	* @param	None
	* @retval None
	*/
void RCC_Configuration(void)
{	
	/* Setup the microcontroller system. Initialize the Embedded Flash Interface,	
		 initialize the PLL and update the SystemFrequency variable. */
	SystemInit();
}

/**
	* @brief	Inserts a delay time.
	* @param	nCount: specifies the delay time length.
	* @retval None
	*/
void Delay(__IO uint32_t nCount)
{
	for(; nCount != 0; nCount--);
}

#ifdef	USE_FULL_ASSERT
/**
	* @brief	Reports the name of the source file and the source line number
	*	 where the assert_param error has occurred.
	* @param	file: pointer to the source file name
	* @param	line: assert_param error line source number
	* @retval None
	*/
void assert_failed(uint8_t* file, uint32_t line)
{
	/* User can add his own implementation to report the file name and line number,
		 ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line) */

	/* Infinite loop */
	while (1)
	{
	}
}
#endif

/**
	* @}
	*/

/**
	* @}
	*/

/******************* (C) COPYRIGHT 2009 STMicroelectronics *****END OF FILE****/
